@@ -9,9 +9,9 @@ use Carp;
 use 5.010;
 
 use parent qw/Bio::Root::Root/;
-use YAML qw/freeze thaw/;
+use YAML::XS qw/freeze thaw/;
 use Data::Dumper;
-our $VERSION = '0.083'; # VERSION
+our $VERSION = '0.090'; # VERSION
 
 our $MAP_PREFIX = 's';
 our $IDLENGTH   = 9;
