@@ -7,7 +7,7 @@ use strict;
 use Carp;
 use FindBin;
 use File::Spec;
-use Scalar::Util qw/readonly/;
+use Scalar::Util              qw/readonly/;
 use Bio::Gonzales::Util::File qw/slurpc/;
 use Bio::Gonzales::Util::Cerial;
 use Bio::Gonzales::Util::Development::File;
@@ -24,32 +24,32 @@ use POSIX;
 
 use 5.010;
 
-our $VERSION = '0.083'; # VERSION
+our $VERSION = '0.090'; # VERSION
 
-has '_config_key_cache' => ( is => 'rw', default => sub { {} } );
-has '_nfi_cache'        => ( is => 'rw', default => sub { {} } );
-has 'analysis_version'  => ( is => 'rw', builder => '_build_analysis_version' );
-has '_substitute_conf' => ( is => 'rw', lazy_build => 1 );
-has 'config'           => ( is => 'rw', lazy_build => 1 );
-has 'merge_av_config'  => ( is => 'rw', default    => 1 );
-has 'log'              => ( is => 'rw', builder    => '_build_log' );
-has 'config_file'      => ( is => 'rw', default    => 'gonz.conf.yml' );
-has 'analysis_name'    => ( is => 'rw', lazy_build => 1 );
+has '_config_key_cache' => (is => 'rw', default    => sub { {} });
+has '_nfi_cache'        => (is => 'rw', default    => sub { {} });
+has 'analysis_version'  => (is => 'rw', builder    => '_build_analysis_version');
+has '_substitute_conf'  => (is => 'rw', lazy_build => 1);
+has 'config'            => (is => 'rw', lazy_build => 1);
+has 'merge_av_config'   => (is => 'rw', default    => 1);
+has 'log'               => (is => 'rw', builder    => '_build_log');
+has 'config_file'       => (is => 'rw', default    => 'gonz.conf.yml');
+has 'analysis_name'     => (is => 'rw', lazy_build => 1);
 
 sub _build_analysis_name {
   my ($self) = @_;
 
-  return ( File::Spec->splitdir( File::Spec->rel2abs('.') ) )[-1];
+  return (File::Spec->splitdir(File::Spec->rel2abs('.')))[-1];
 }
 
 sub _build_analysis_version {
   my ($self) = @_;
 
   my $av;
-  if ( $ENV{ANALYSIS_VERSION} ) {
+  if ($ENV{ANALYSIS_VERSION}) {
     $av = $ENV{ANALYSIS_VERSION};
-  } elsif ( -f 'av' ) {
-    $av = ( slurpc('av') )[0];
+  } elsif (-f 'av') {
+    $av = (slurpc('av'))[0];
   } else {
     carp "using current dir as output dir";
     $av = '.';
@@ -72,17 +72,17 @@ sub _build__substitute_conf {
   return sub {
     return unless defined $_[0];
     # boolean values in YAML::XS are readonly. Take care of this.
-    return $_[0] if(readonly($_[0]));
+    return $_[0] if (readonly($_[0]));
 
-      $_[0] =~ s{ ^ ~ ( [^/]* ) }
+    $_[0] =~ s{ ^ ~ ( [^/]* ) }
             { $1
                 ? (getpwnam($1))[7]
                 : ( $ENV{HOME} || (getpwuid($>))[7] )
             }ex;
 
-      $_[0] =~ s{__($subsre)(?:\((.+?)\))?__}{ $subs{ $1 }->( $2 ? split( /,/, $2 ) : () ) }eg;
+    $_[0] =~ s{__($subsre)(?:\((.+?)\))?__}{ $subs{ $1 }->( $2 ? split( /,/, $2 ) : () ) }eg;
     return $_[0];
-    }
+  }
 }
 
 sub _build_log {
@@ -102,22 +102,22 @@ sub _build_config {
   my $conf_f = $self->config_file;
   my $sub    = $self->_substitute_conf;
 
-  if ( -f $conf_f ) {
+  if (-f $conf_f) {
     $conf = yslurp($conf_f);
     $conf //= {};
 
     confess "configuration file >> $conf_f << is not a hash/dictionary structure"
-      if ( ref $conf ne 'HASH' );
+      if (ref $conf ne 'HASH');
     $self->log->info("reading >> $conf_f <<");
     rmap_to { $sub->($_) } VALUE, $conf;
   }
 
-  my $av_conf_f = join( ".", $self->analysis_version, "conf", "yml" );
-  if ( $self->merge_av_config && $av_conf_f !~ /^\./ && -f $av_conf_f ) {
+  my $av_conf_f = join(".", $self->analysis_version, "conf", "yml");
+  if ($self->merge_av_config && $av_conf_f !~ /^\./ && -f $av_conf_f) {
 
     my $av_conf = yslurp($av_conf_f);
     confess "configuration file >> $av_conf_f << is not a hash/dictionary structure"
-      if ( ref $av_conf ne 'HASH' );
+      if (ref $av_conf ne 'HASH');
 
     $self->log->info("reading >> $av_conf_f <<");
     rmap_to { $sub->($_) } VALUE, $conf;
@@ -133,7 +133,7 @@ sub BUILD {
   my $av = $self->analysis_version;
 
   $self->log->info("invoked ($av)")    # if a script is run, log it
-    if ( !$ENV{GONZLOG_SILENT} );
+    if (!$ENV{GONZLOG_SILENT});
 }
 
 around 'analysis_version' => sub {
@@ -143,17 +143,17 @@ around 'analysis_version' => sub {
   return $self->$orig()
     unless @_;
 
-  return $self->$orig( _prepare_av(shift) );
+  return $self->$orig(_prepare_av(shift));
 };
 
 sub _prepare_av {
   my $av = shift;
-  if ( !$av ) {
+  if (!$av) {
     return '.';
-  } elsif ( $av =~ /^[-A-Za-z_.0-9]+$/ ) {
-    mkdir $av unless ( -d $av );
+  } elsif ($av =~ /^[-A-Za-z_.0-9]+$/) {
+    mkdir $av unless (-d $av);
   } else {
-    carp "analysis version not or not correctly specified, variable contains: " . ( $av // 'nothing' );
+    carp "analysis version not or not correctly specified, variable contains: " . ($av // 'nothing');
     carp "using current dir as output dir";
     return '.';
   }
@@ -171,32 +171,33 @@ sub nfi {
 
   # only log it once per filename
   $self->log->info("(nfi) > $f <")
-    unless ( $self->_nfi_cache->{$f}++ );
+    unless ($self->_nfi_cache->{$f}++);
 
   return $f;
 }
 
 sub _nfi {
   my $self = shift;
-  return File::Spec->catfile( $self->analysis_version, @_ );
+  return File::Spec->catfile($self->analysis_version, @_);
 }
 
 sub conf {
-  my ( $self, @keys ) = @_;
+  my ($self, @keys) = @_;
+  @keys = split(/\./, join(".", @keys));
 
   my $data = $self->config;
 
   for my $k (@keys) {
     confess "empty key supplied" unless ($k);
     my $r = ref $data;
-    if ( $r && $r eq 'HASH' ) {
-      if ( exists( $data->{$k} ) ) {
+    if ($r && $r eq 'HASH') {
+      if (exists($data->{$k})) {
         $data = $data->{$k};
       } else {
         $self->log->fatal_confess("$k not found in gonzconf");
       }
-    } elsif ( $r && $r eq 'ARRAY' ) {
-      if ( exists( $data->[$k] ) ) {
+    } elsif ($r && $r eq 'ARRAY') {
+      if (exists($data->[$k])) {
         $data = $data->[$k];
       } else {
         $self->log->fatal_confess("$k not found in gonzconf");
@@ -206,13 +207,13 @@ sub conf {
     }
   }
   if (@keys) {
-    my $k = join( " ", @keys );
-    $self->log->info( "(gonzconf) > " . $k . " <", np($data) )
-      unless ( $self->_config_key_cache->{ '_' . $k }++ );
+    my $k = join(" ", @keys);
+    $self->log->info("(gonzconf) > " . $k . " <", np($data))
+      unless ($self->_config_key_cache->{ '_' . $k }++);
 
   } else {
-    $self->log->info( "(gonzconf) dump", np($data) )
-      unless ( $self->_config_key_cache->{'_'}++ );
+    $self->log->info("(gonzconf) all", np($data))
+      unless ($self->_config_key_cache->{'_'}++);
   }
   return $data;
 }
@@ -230,13 +231,19 @@ sub path_to {
 
   confess "Could not find project home"
     unless ($home);
-  return File::Spec->catfile( $home, @_ );
+  return File::Spec->catfile($home, @_);
+}
+
+sub analysis_root {
+  my $self = shift;
+
+  return $self->path_to("analysis");
 }
 
 sub analysis_path {
   my $self = shift;
 
-  return $self->path_to( "analysis", @_ );
+  return $self->path_to("analysis", $self->analysis_version, @_);
 }
 
 __PACKAGE__->meta->make_immutable();
