@@ -7,15 +7,16 @@ use strict;
 use Carp;
 
 use String::ShellQuote;
+use IO::Prompt::Tiny qw/prompt/;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.083'; # VERSION
+our $VERSION = '0.090'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
 @EXPORT_OK
-  = qw(undef_slice slice invslice flatten hash_merge as_arrayref sys_pipe sys_fmt sys_pipe_fatal deep_value);
+  = qw(undef_slice slice invslice flatten hash_merge as_arrayref sys_pipe sys_fmt sys_pipe_fatal deep_value ask);
 
 sub slice {
   my ( $hr, @k ) = @_;
@@ -130,6 +131,13 @@ sub sys_pipe_fatal {
   system($cmd) == 0 or croak "system " . join( " ", @_ ) . " FAILED: $? ## $!";
 }
 
+sub ask {
+  my $question    = shift;
+  my $answer = prompt("$question (y/n)", "n");
+  return $answer =~ /^y/i;
+}
+
+
 sub deep_value {
   my ( $data, $keys ) = ( shift, shift );
 
