@@ -1,7 +1,9 @@
-#!/usr/bin/env perl
 #Copyright (c) 2010 Joachim Bargsten <code at bargsten dot org>. All rights reserved.
 
 package Bio::Gonzales::Util::Development::Module;
+
+use strict;
+use warnings;
 use Carp;
 
 use File::Spec;
@@ -15,7 +17,7 @@ use Cwd;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.083'; # VERSION
+our $VERSION = '0.090'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
